@@ -2,7 +2,7 @@ package VIC::Grammar;
 use strict;
 use warnings;
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 $VERSION = eval $VERSION;
 
 use Pegex::Base;
@@ -14,7 +14,7 @@ sub make_tree {   # Generated/Inlined by Pegex::Grammar (0.57)
   {
     '+grammar' => 'vic',
     '+toprule' => 'program',
-    '+version' => '0.2.4',
+    '+version' => '0.2.5',
     'COMMA' => {
       '.rgx' => qr/\G,/
     },
@@ -116,6 +116,9 @@ sub make_tree {   # Generated/Inlined by Pegex::Grammar (0.57)
             {
               '.ref' => 'number_units'
             },
+            {
+              '.ref' => 'real_number'
+            },
             {
               '.ref' => 'number'
             },
@@ -733,6 +736,16 @@ sub make_tree {   # Generated/Inlined by Pegex::Grammar (0.57)
         }
       ]
     },
+    'real_number' => {
+      '.any' => [
+        {
+          '.rgx' => qr/\G(\-?[0-9]*\.[0-9]+)/
+        },
+        {
+          '.rgx' => qr/\G(\-?[0-9]+\.[0-9]*)/
+        }
+      ]
+    },
     'rhs_expr' => {
       '.all' => [
         {
