@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 $VERSION = eval $VERSION;
 
 use VIC::PIC::Gpsim;
@@ -121,6 +121,17 @@ sub list_chip_features {
     };
 }
 
+sub print_pinout {
+    my $chip = shift;
+    my $ctype = &_get_pic_type($chip);
+    unless (defined $ctype) {
+        carp "Chip $chip is not supported\n";
+        return;
+    }
+    my $obj = __PACKAGE__->new($chip);
+    return $obj->print_pinout;
+}
+
 1;
 
 =encoding utf8
